@@ -308,7 +308,6 @@ def _getnextLDAPGIDNumber(start = 1000, end = 99999999):
 	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
 	hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
 	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")
-	siteSuffix = hubzero.config.ldapconfig.getLDAPSiteSuffix()
 	
 	ldapServer = hubzero.config.webconfig.getComponentParam("com_system", "ldap_primary")
 	l = ldap.initialize(ldapServer)
@@ -319,7 +318,7 @@ def _getnextLDAPGIDNumber(start = 1000, end = 99999999):
 	# get all groups from ldap
 	try:
 		r = l.search_s(
-			"ou=groups," + siteSuffix, 
+			"ou=groups," + hubLDAPBaseDN, 
 			ldap.SCOPE_SUBTREE, 
 			'(objectClass=posixGroup)',   
 			['cn', 'gidNumber'])
@@ -449,7 +448,6 @@ def _syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True, g
 	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
 	hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
 	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")
-	siteSuffix = hubzero.config.ldapconfig.getLDAPSiteSuffix()
 	ldapServer = hubzero.config.webconfig.getComponentParam("com_system", "ldap_primary")
 	
 	if purgeorphans:
@@ -471,9 +469,9 @@ def _syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True, g
 		r = None
 		try:
 			if group == '*':
-				r = l.search_s("ou=groups," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixGroup)',   ['cn'])
+				r = l.search_s("ou=groups," + hubLDAPBaseDN, ldap.SCOPE_SUBTREE, '(objectClass=posixGroup)',   ['cn'])
 			else:
-				r = l.search_s("cn="+group+",ou=groups," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixGroup)',   ['cn']) 
+				r = l.search_s("cn="+group+",ou=groups," + hubLDAPBaseDN, ldap.SCOPE_SUBTREE, '(objectClass=posixGroup)',   ['cn']) 
 
 		except ldap.NO_SUCH_OBJECT:
 			if debug:
@@ -549,14 +547,13 @@ def _delete_ldap_users(args):
 		hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
 		hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
 		hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")
-		siteSuffix = hubzero.config.ldapconfig.getLDAPSiteSuffix()
 		
 		ldapServer = hubzero.config.webconfig.getComponentParam("com_system", "ldap_primary")
 		l = ldap.initialize(ldapServer)
 		l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
 
 		try:
-			r = l.search_s("ou=users," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixAccount)', ['uid'])
+			r = l.search_s("ou=users," + hubLDAPBaseDN, ldap.SCOPE_SUBTREE, '(objectClass=posixAccount)', ['uid'])
 
 			for dn,entry in r:
 				uid = str(entry['uid'][0])
